---
title: Dummy Example README
---

# About

This example show how to create a [minimal subclass of the Experiment class](src/experiment.py) and return a value calculated from parameters in the [configuration file](conf/config.yaml).

# Usage

~~~sh
hl-run --multirun
mlflow ui
~~~

The last command will print a URI that you can open in a browser to compare the results of the different parameter combinations.
